@@ -528,11 +528,11 @@ class VariableClAutopartitionScheme(AutopartitionHelper,Variable,AutoPartition):
 
     def get(self):
         if self.Get('os_uefi_set') == 'on':
-            return ["uefi","swap","root","data","home"]
+            return ["uefi","swap","data","home"]
         elif self.Get('cl_autopartition_table') == 'gpt':
-            return ["swap","root","data","home","grub"]
+            return ["swap","data","home","grub"]
         else:
-            return ["swap","root","data","home"]
+            return ["swap","data","home"]
 
     def choice(self):
         return [
