@@ -97,6 +97,7 @@ class VariableOsDeviceData(ReadonlyTableVariable):
               'os_device_ssd_set',
               'os_device_virtual_set',
               'os_device_map',
+              'os_device_syspath',
               'os_device_name',
               'os_device_size']
 
@@ -226,24 +227,45 @@ class VariableOsDeviceSsdSet(ReadonlyVariable):
                    zip(self.Get('os_device_dev'),
                        self.Get('os_device_name')))
 
+class VariableOsDeviceSyspath(ReadonlyVariable):
+    """
+    Table on device
+    """
+    type = "list"
+    udev_property = 'DEVPATH'
+
+    def get(self):
+        """Get device partition table"""
+        def getSysPath(device):
+            prop = getUdevDeviceInfo(name=device)
+            syspath = prop.get(self.udev_property, "")
+            return syspath
+
+        return [getSysPath(x) for x in self.Get('os_device_dev')]
+
+
 class VariableOsDeviceVirtualSet(ReadonlyVariable):
     """
     Table on device
     """
     type = "list"
-    virtual_names = ("VBOX",)
+    virtual_names = ("VBOX","VMWare")
+    virtual_syspath = ("virtio",)
 
     def get(self):
         """Get device partition table"""
-        def isVirtual(device, name):
+        def isVirtual(device, name, syspath):
             if any(x in name for x in self.virtual_names):
                 return "on"
+            elif any(x in syspath for x in self.virtual_syspath):
+                return "on"
             else:
                 return "off"
 
         return map(lambda x: isVirtual(*x),
                    zip(self.Get('os_device_dev'),
-                       self.Get('os_device_name')))
+                       self.Get('os_device_name'),
+                       self.Get('os_device_syspath')))
 
 
 class VariableOsDeviceTable(ReadonlyVariable):
@@ -736,7 +758,7 @@ class VariableOsLocationSource(LocationHelper,DeviceHelper,Variable):
             if choice:
                 return self.Get('os_disk_dev')+self.Get('os_bind_path')
             else:
-                devFrom = self.Get('os_install_dev_from')
+                devFrom = self.Get('cl_install_dev_from')
                 if self.Get('os_install_scratch') == 'on':
                     return self.Select('os_disk_dev',
                                        where='os_disk_mount',
@@ -834,7 +856,7 @@ class VariableOsLocationDest(LocationHelper,Variable):
                    self.Get('cl_autopartition_bind_mountpoint')
         else:
             source = self.Get('os_location_source')
-            installFrom = self.Get('os_install_dev_from')
+            installFrom = self.Get('cl_install_dev_from')
             singleDevice = self.Get('os_install_disk_single')
             def installMountPoint(info):
                 dev,mount = info
