@@ -72,6 +72,8 @@ class Wsdl(WsdlBase):
                         'cl_image_new_only')),
             lambda group:group(_("Allocate drive space"),
                 normal=('cl_autopartition_set',),
+                hide=('cl_autopartition_set',),
+                brief=('cl_autopartition_brief_set',),
                 expert=('cl_autopartition_scheme',
                         'cl_autopartition_table','cl_autopartition_root_size',
                         'cl_autopartition_swap_size',
@@ -80,8 +82,8 @@ class Wsdl(WsdlBase):
             lambda group:group(_("Mount points"),
                 normal=('os_location_data',),
                 hide=('os_location_data','os_install_mbr','os_install_uefi_set'),
-                brief_force=('os_location_brief_data','os_install_bootloader',
-                             'os_install_uefi_set'),
+                brief_force=('os_location_brief_data','os_install_bootloader'),
+                brief=('os_install_uefi_brief_set',),
                 expert=('cl_uuid_set',
                         'os_install_root_type',
                         'os_install_mbr',
@@ -137,7 +139,8 @@ class Wsdl(WsdlBase):
         'method_name':"install_pxe",
         'category':__("Installation"),
         'title':__("PXE Install"),
-        'image':'network-server,preferences-desktop-remote-desktop',
+        'image':('gnome-network-properties,network-server,'
+                'preferences-desktop-remote-desktop'),
         'command':'cl-install-pxe',
         'gui':True,
         'rights':['installpxe'],
@@ -187,7 +190,7 @@ class Wsdl(WsdlBase):
         'method_name':"setup_network",
         'category':__("Configuration"),
         'title':__("Network"),
-        'image':'gnome-network-properties,'
+        'image':'network-workgroup,'
                 'network-idle,preferences-system-network',
         'command':'cl-setup-network',
         'gui':True,
@@ -212,7 +215,7 @@ class Wsdl(WsdlBase):
         'method_name':"setup_system",
         'category':__("Configuration"),
         'title':__("System"),
-        'image':'applications-ide,system-run,system,computer',
+        'image':'run-build,applications-ide,system-run,system,computer',
         'command':'cl-setup-system',
         'gui':True,
         'rights':['setupsystem'],
@@ -278,7 +281,7 @@ class Wsdl(WsdlBase):
         'method_name':"setup_session",
         'category':__("Configuration"),
         'title':__("Session"),
-        'image':'session-properties',
+        'image':'system-lock-screen',
         'command':'cl-setup-session',
         'gui':True,
         'rights':['setupsession'],
